@@ -238,17 +238,17 @@ class Phonetic_Manipulation():
 		# Low Front Vowels
 		self.low_front_unrounded = self.__clarify_phones__(vowels, phones, self.low, self.front_unrounded)
 		self.low_front_rounded = self.__clarify_phones__(vowels, phones, self.low, self.front_rounded)
-		self.low_front = self.low_front_unrounded_tense + self.low_front_rounded_tense
+		self.low_front = self.low_front_unrounded + self.low_front_rounded
 
 		# Low Central Vowels
 		self.low_central_unrounded = self.__clarify_phones__(vowels, phones, self.low, self.mid_unrounded)
 		self.low_central_rounded = self.__clarify_phones__(vowels, phones, self.low, self.mid_rounded)
-		self.low_central = self.low_central_rounded_tense + self.low_central_unrounded_tense
+		self.low_central = self.low_central_rounded + self.low_central_unrounded
 
 		# Low Back Vowels
 		self.low_back_unrounded = self.__clarify_phones__(vowels, phones, self.low, self.back_unrounded)
 		self.low_back_rounded = self.__clarify_phones__(vowels, phones, self.low, self.back_rounded)
-		self.low_back = self.low_back_rounded_tense + self.low_back_unrounded_tense
+		self.low_back = self.low_back_rounded + self.low_back_unrounded
 
 		if phones == 'IPA':
 			self.diphthongs = self.vowels + u'\u0361' + self.vowels
